What is Axiom?
==============

Axiom is a utility designed to process and validate metadata for numerical model output.

Currently Axiom can:

- Validate NetCDF files against a standard (schema).
- Produce a report of validation.
- Apply a schema to data with ill-defined metadata.
- Apply Data Reference Syntax